api.alarms.v1 package — Argus-Toolbelt 1.0 documentation

# api.alarms.v1 package

## Submodules

## api.alarms.v1.alarm module

Autogenerated API

`api.alarms.v1.alarm.` `get_alarm_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get alarm by Id (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of alarm
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 460, “limit”: 451, “responseCode”: 200, “count”: 401, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Store behind before ready show marriage situation.”, “messageTemplate”: “Company entire morning family main meet material.”, “field”: “Pattern above anyone ability.”, “parameter”: {}, “timestamp”: 337797720}], “currentPage”: 51, “size”: 602}

`api.alarms.v1.alarm.` `get_alarms`(keywords: list = None, keywordField: list = None, keywordMatch: str = 'all', offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all alarms (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search keywordMatch (str) – Set match strategy for keyword search offset (int) – Skip a number of alarms limit (int) – Maximum number of returned alarms
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 709, “limit”: 208, “responseCode”: 200, “count”: 133, “data”: [{“id”: 599, “mappings”: [{“lastUpdatedTimestamp”: 919115033, “comments”: [{“timestamp”: 951788795, “comment”: “Avoid within heavy scene.”}], “mappedTimestamp”: 1034322276, “firstTriggeredTimestamp”: 744054806, “lastTriggeredTimestamp”: 1103068908, “triggerAmount”: 464, “signature”: “Ahead hit administration pass.”, “flags”: [“DEFAULT_BLOCK”]}], “comments”: [{“timestamp”: 403296644, “comment”: “Strategy season character vote project idea hand at.”}], “references”: [“Own evening summer have appear activity value.”], “labels”: [“Decide attorney look provide.”], “info”: “Test nature everything put push modern interesting which.”, “description”: “End whole wonder Mrs positive hot fear.”, “links”: [“Full good parent pull edge approach result article.”], “createdByUser”: {“id”: 940, “customerID”: 458, “userName”: “danielsanchez”, “name”: “Jennifer Miles”}, “createdTimestamp”: 1357973567, “lastUpdatedByUser”: {“id”: 690, “customerID”: 857, “userName”: “sean67”, “name”: “Lauren Sanchez”}, “lastUpdatedTimestamp”: 722404927, “lastCheckedByUser”: {“id”: 116, “customerID”: 598, “userName”: “vwong”, “name”: “Melissa Stuart”}, “lastCheckTimestamp”: 633311272, “nextCheckTimestamp”: 48376418, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Authority future trouble society one whether seek wear.”, “messageTemplate”: “Magazine board may never process.”, “field”: “Mr indeed often modern piece especially.”, “parameter”: {}, “timestamp”: 451205394}], “currentPage”: 164, “size”: 660}

`api.alarms.v1.alarm.` `search_alarms`(limit: int = None, offset: int = None, subCriteria: list = None, attackCategoryID: list = None, alarmID: list = None, alarmReferences: list = None, labels: list = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, keywords: list = None, keywordFieldStrategy: list = None, signature: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, timeMatchStrategy: str = 'any', keywordMatchStrategy: str = 'all', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeMappings: bool = 'False', includeComments: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all alarms matching a given search criteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – attackCategoryID (list) – A set of IDs for attack categories (alarm category). alarmID (list) – A set of IDs for alarms. alarmReferences (list) – A set of references. It does an exact match. labels (list) – A set of labels. It does an exact match. startTimestamp (int) – Only include alarms based on the set TimeFieldStrategy and TimeMatchStrategy (start timestamp) endTimestamp (int) – Only include alarms based on the set TimeFieldStrategy and TimeMatchStrategy (end timestamp) timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match. (default lastUpdatedTimestamp) keywords (list) – A set of keywords matched against alarms based on the set KeywordFieldStrategy and KeywordMatchStrategy. keywordFieldStrategy (list) – KeywordFieldStrategy to define which field(s) to match against keywords. (default all) signature (list) – A set of signatures. It does an exact match. sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. timeMatchStrategy (str) – TimeMatchStrategy to define how to match startTimestamp and endTimestamp with fields. (default any) keywordMatchStrategy (str) – KeywordMatchStrategy to define how to match keywords with fields. (default all) includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeMappings (bool) – Set to include mappings in the search result. (default false) includeComments (bool) – Set to include comments in the search result. (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 405, “limit”: 812, “responseCode”: 200, “count”: 442, “data”: [{“id”: 659, “mappings”: [{“lastUpdatedTimestamp”: 410960231, “comments”: [{“timestamp”: 490973472, “comment”: “Lay want edge.”}], “mappedTimestamp”: 45339727, “firstTriggeredTimestamp”: 120039883, “lastTriggeredTimestamp”: 440912034, “triggerAmount”: 976, “signature”: “Author by since perhaps anything.”, “flags”: [“ISS_SIGNATURE”]}], “comments”: [{“timestamp”: 470654339, “comment”: “Thing rock success arrive spring.”}], “references”: [“Black guess this subject difficult between fast.”], “labels”: [“Its read city on.”], “info”: “Affect white back company never.”, “description”: “Beautiful material but.”, “links”: [“Stop card minute western market election establish could.”], “createdByUser”: {“id”: 407, “customerID”: 819, “userName”: “bradleyjessica”, “name”: “Kayla Hammond”}, “createdTimestamp”: 531340933, “lastUpdatedByUser”: {“id”: 304, “customerID”: 790, “userName”: “mark59”, “name”: “Ryan Parker”}, “lastUpdatedTimestamp”: 257399928, “lastCheckedByUser”: {“id”: 988, “customerID”: 778, “userName”: “lisahaynes”, “name”: “James Jackson”}, “lastCheckTimestamp”: 1470981360, “nextCheckTimestamp”: 488594932, “flags”: [“DISABLED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Population all young get believe interview.”, “messageTemplate”: “Figure couple more goal near discussion.”, “field”: “Build machine senior hour represent personal ask.”, “parameter”: {}, “timestamp”: 846439441}], “currentPage”: 644, “size”: 368}

## api.alarms.v1.category module

Autogenerated API

`api.alarms.v1.category.` `get_categories`(keywords: list = None, keywordField: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all categories (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Filter categories by keywords keywordField (list) – Set field strategy for keyword search offset (int) – Skip a number of categories limit (int) – Maximum number of returned categories keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 542, “limit”: 898, “responseCode”: 200, “count”: 258, “data”: [{“id”: 768, “info”: “Then task stand increase agent.”, “name”: “Jose Romero”, “flags”: [“RECONNAISSANCE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Itself want possible special not.”, “messageTemplate”: “Begin hard even necessary few.”, “field”: “Low may must since response dark ball.”, “parameter”: {}, “timestamp”: 1236470465}], “currentPage”: 396, “size”: 194}

`api.alarms.v1.category.` `get_category_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get category by Id (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of category
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 278, “limit”: 154, “responseCode”: 200, “count”: 744, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Economic quite important unit tax summer describe.”, “messageTemplate”: “Quality our trade always yet.”, “field”: “Although physical necessary western election language have.”, “parameter”: {}, “timestamp”: 279520474}], “currentPage”: 833, “size”: 966}

`api.alarms.v1.category.` `search_categories`(limit: int = None, offset: int = None, subCriteria: list = None, attackCategoryID: list = None, keywords: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, keywordMatchStrategy: str = 'all', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all categories matching a given search criteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – attackCategoryID (list) – A set of IDs for attack categories (alarm category). keywords (list) – A set of keywords matched against categories based on the set KeywordFieldStrategy and KeywordMatchStrategy. keywordFieldStrategy (list) – KeywordFieldStrategy to define which field(s) to match against keywords. (default all) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. keywordMatchStrategy (str) – KeywordMatchStrategy to define how to match keywords with fields. (default all) includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 206, “limit”: 42, “responseCode”: 200, “count”: 399, “data”: [{“id”: 361, “info”: “Evidence open anyone what left several economy four.”, “name”: “Alexander Hurst”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Program appear law what kind shoulder center.”, “messageTemplate”: “Modern center interview speak she.”, “field”: “Help realize song.”, “parameter”: {}, “timestamp”: 1021965963}], “currentPage”: 285, “size”: 461}

## api.alarms.v1.signature module

Autogenerated API

`api.alarms.v1.signature.` `get_signatures`(keywords: list = None, keywordField: list = None, keywordMatch: str = 'all', offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all signatures including alarms if mapped (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search keywordMatch (str) – Set match strategy for keyword search offset (int) – Skip a number of signatures limit (int) – Maximum number of returned signatures
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 748, “limit”: 510, “responseCode”: 200, “count”: 700, “data”: [{“lastUpdatedByUser”: {“id”: 277, “customerID”: 549, “userName”: “morgan38”, “name”: “Robert Lewis”}, “lastUpdatedTimestamp”: 427028982, “comments”: [{“timestamp”: 504212842, “comment”: “Stuff across word too.”}], “mappedTimestamp”: 1010314417, “mappedByUser”: {“id”: 504, “customerID”: 553, “userName”: “anita76”, “name”: “Connie Dean”}, “firstTriggeredTimestamp”: 141026889, “lastTriggeredTimestamp”: 378439602, “triggerAmount”: 89, “signature”: “Call peace enter play.”, “flags”: [“ISS_SIGNATURE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Itself idea road job TV scientist cultural little.”, “messageTemplate”: “Million sea live floor believe.”, “field”: “Can energy organization bank almost.”, “parameter”: {}, “timestamp”: 553818820}], “currentPage”: 929, “size”: 589}

`api.alarms.v1.signature.` `search_signatures`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, attackCategoryID: list = None, alarmID: list = None, signature: list = None, minTriggerAmount: int = None, maxTriggerAmount: int = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, keywords: list = None, keywordFieldStrategy: list = None, sortBy: list = None, timeMatchStrategy: str = 'any', keywordMatchStrategy: str = 'all', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all signatures matching a given search criteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – attackCategoryID (list) – A set of IDs for attack categories (alarm category). alarmID (list) – A set of IDs for alarms. signature (list) – A set of signatures. It does an exact match. minTriggerAmount (int) – Minimum trigger amount, default 0 means disabled maxTriggerAmount (int) – Maximum trigger amount, default 0 means disabled startTimestamp (int) – Only include mappings based on the set TimeFieldStrategy and TimeMatchStrategy (start timestamp) endTimestamp (int) – Only include mappings based on the set TimeFieldStrategy and TimeMatchStrategy (end timestamp) timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match. (default lastTriggeredTimestamp) keywords (list) – A set of keywords matched against mappings based on the set KeywordFieldStrategy and KeywordMatchStrategy. keywordFieldStrategy (list) – KeywordFieldStrategy to define which field(s) to match against keywords. (default all) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). timeMatchStrategy (str) – TimeMatchStrategy to define how to match startTimestamp and endTimestamp with fields. (default any) keywordMatchStrategy (str) – KeywordMatchStrategy to define how to match keywords with fields. (default all) includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 811, “limit”: 182, “responseCode”: 200, “count”: 107, “data”: [{“lastUpdatedByUser”: {“id”: 262, “customerID”: 438, “userName”: “awhite”, “name”: “Elizabeth Tran”}, “lastUpdatedTimestamp”: 895941072, “comments”: [{“timestamp”: 912386313, “comment”: “Quickly you forward rich.”}], “mappedTimestamp”: 1326402343, “mappedByUser”: {“id”: 594, “customerID”: 134, “userName”: “mckenziebrandon”, “name”: “Terry Kim”}, “firstTriggeredTimestamp”: 95512144, “lastTriggeredTimestamp”: 1295340724, “triggerAmount”: 694, “signature”: “Character serve produce leader serious.”, “flags”: [“DEFAULT_BLOCK”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Worker stuff off likely blue modern avoid put.”, “messageTemplate”: “About yard last of seat bad eat.”, “field”: “Foot account draw call throughout part.”, “parameter”: {}, “timestamp”: 1400951749}], “currentPage”: 478, “size”: 794}

## Module contents